==> haskell-shake-0.16.3-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-shake.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shake
version: 0.16.3
id: shake-0.16.3-6U5Tryge68T2YXoOY2A39R
key: shake-0.16.3-6U5Tryge68T2YXoOY2A39R
license: BSD3
copyright: Neil Mitchell 2011-2018
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: http://shakebuild.com
synopsis: Build system library, like Make, but more accurate dependencies.
description:
    Shake is a Haskell library for writing build systems - designed as a
    replacement for @make@. See "Development.Shake" for an introduction,
    including an example. Further examples are included in the Cabal tarball,
    under the @Examples@ directory. The homepage contains links to a user
    manual, an academic paper and further information:
    <http://shakebuild.com>
    .
    To use Shake the user writes a Haskell program
    that imports "Development.Shake", defines some build rules, and calls
    the '\''Development.Shake.shakeArgs'\'' function. Thanks to do notation and infix
    operators, a simple Shake build system
    is not too dissimilar from a simple Makefile. However, as build systems
    get more complex, Shake is able to take advantage of the excellent
    abstraction facilities offered by Haskell and easily support much larger
    projects. The Shake library provides all the standard features available in other
    build systems, including automatic parallelism and minimal rebuilds.
    Shake also provides more accurate dependency tracking, including seamless
    support for generated files, and dependencies on system information
    (e.g. compiler version).
category: Development, Shake
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Development.Shake Development.Shake.Classes
    Development.Shake.Command Development.Shake.Config
    Development.Shake.FilePath Development.Shake.Forward
    Development.Shake.Rule Development.Shake.Util
hidden-modules: Development.Ninja.Env Development.Ninja.Lexer
                Development.Ninja.Parse Development.Ninja.Type
                Development.Shake.Internal.Args
                Development.Shake.Internal.CmdOption
                Development.Shake.Internal.Core.Action
                Development.Shake.Internal.Core.Database
                Development.Shake.Internal.Core.Monad
                Development.Shake.Internal.Core.Pool
                Development.Shake.Internal.Core.Rendezvous
                Development.Shake.Internal.Core.Rules
                Development.Shake.Internal.Core.Run
                Development.Shake.Internal.Core.Storage
                Development.Shake.Internal.Core.Types
                Development.Shake.Internal.Demo Development.Shake.Internal.Derived
                Development.Shake.Internal.Errors
                Development.Shake.Internal.FileInfo
                Development.Shake.Internal.FileName
                Development.Shake.Internal.FilePattern
                Development.Shake.Internal.Options Development.Shake.Internal.Paths
                Development.Shake.Internal.Profile
                Development.Shake.Internal.Progress
                Development.Shake.Internal.Resource
                Development.Shake.Internal.Rules.Directory
                Development.Shake.Internal.Rules.File
                Development.Shake.Internal.Rules.Files
                Development.Shake.Internal.Rules.Oracle
                Development.Shake.Internal.Rules.OrderOnly
                Development.Shake.Internal.Rules.Rerun
                Development.Shake.Internal.Shake Development.Shake.Internal.Value
                General.Bag General.Bilist General.Binary General.Chunks
                General.Cleanup General.Concurrent General.Extra General.FileLock
                General.GetOpt General.Ids General.Intern General.ListBuilder
                General.Makefile General.Process General.Template General.Timing
                Paths_shake
abi: 1fcf10d6d650bbbf20bb7fe910976348
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/shake-0.16.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/shake-0.16.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-shake
hs-libraries: HSshake-0.16.3-6U5Tryge68T2YXoOY2A39R
depends:
    base-4.10.1.0 binary-0.8.5.1 bytestring-0.10.8.2 deepseq-1.4.3.0
    directory-1.3.0.2 extra-1.6.4-IR1oQDuzGtgJSLCzznTeLE
    filepath-1.4.1.2 hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    js-flot-0.8.3-BVv7WjS6mgVJLBMR8vaufn
    js-jquery-3.3.1-IRm9CyYZz3bLOvrW1ytpLd
    primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo process-1.6.1.0
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We time-1.8.0.2 transformers-0.5.2.0
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             extra-1.6.4-IR1oQDuzGtgJSLCzznTeLE=58fe223e93bb16a10e7d42b22a8195bc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             js-flot-0.8.3-BVv7WjS6mgVJLBMR8vaufn=2106e2792b3341c959c8f349c22f5bf9
             js-jquery-3.3.1-IRm9CyYZz3bLOvrW1ytpLd=074ee7b24f7470018524730917a30154
             primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo=b4457a9f891c4eea587ee58a79b7f0fc
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=368a9f817c8c1b290191231dd0d81d85
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/haskell-shake/html/shake.haddock
haddock-html: /usr/share/doc/haskell-shake/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shake-0.16.3-18-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-shake.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shake
version: 0.16.3
id: shake-0.16.3-AgvGHj3fKO0H0wHGiwgXMo
key: shake-0.16.3-AgvGHj3fKO0H0wHGiwgXMo
license: BSD3
copyright: Neil Mitchell 2011-2018
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: http://shakebuild.com
synopsis: Build system library, like Make, but more accurate dependencies.
description:
    Shake is a Haskell library for writing build systems - designed as a
    replacement for @make@. See "Development.Shake" for an introduction,
    including an example. Further examples are included in the Cabal tarball,
    under the @Examples@ directory. The homepage contains links to a user
    manual, an academic paper and further information:
    <http://shakebuild.com>
    .
    To use Shake the user writes a Haskell program
    that imports "Development.Shake", defines some build rules, and calls
    the '\''Development.Shake.shakeArgs'\'' function. Thanks to do notation and infix
    operators, a simple Shake build system
    is not too dissimilar from a simple Makefile. However, as build systems
    get more complex, Shake is able to take advantage of the excellent
    abstraction facilities offered by Haskell and easily support much larger
    projects. The Shake library provides all the standard features available in other
    build systems, including automatic parallelism and minimal rebuilds.
    Shake also provides more accurate dependency tracking, including seamless
    support for generated files, and dependencies on system information
    (e.g. compiler version).
category: Development, Shake
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Development.Shake Development.Shake.Classes
    Development.Shake.Command Development.Shake.Config
    Development.Shake.FilePath Development.Shake.Forward
    Development.Shake.Rule Development.Shake.Util
hidden-modules: Development.Ninja.Env Development.Ninja.Lexer
                Development.Ninja.Parse Development.Ninja.Type
                Development.Shake.Internal.Args
                Development.Shake.Internal.CmdOption
                Development.Shake.Internal.Core.Action
                Development.Shake.Internal.Core.Database
                Development.Shake.Internal.Core.Monad
                Development.Shake.Internal.Core.Pool
                Development.Shake.Internal.Core.Rendezvous
                Development.Shake.Internal.Core.Rules
                Development.Shake.Internal.Core.Run
                Development.Shake.Internal.Core.Storage
                Development.Shake.Internal.Core.Types
                Development.Shake.Internal.Demo Development.Shake.Internal.Derived
                Development.Shake.Internal.Errors
                Development.Shake.Internal.FileInfo
                Development.Shake.Internal.FileName
                Development.Shake.Internal.FilePattern
                Development.Shake.Internal.Options Development.Shake.Internal.Paths
                Development.Shake.Internal.Profile
                Development.Shake.Internal.Progress
                Development.Shake.Internal.Resource
                Development.Shake.Internal.Rules.Directory
                Development.Shake.Internal.Rules.File
                Development.Shake.Internal.Rules.Files
                Development.Shake.Internal.Rules.Oracle
                Development.Shake.Internal.Rules.OrderOnly
                Development.Shake.Internal.Rules.Rerun
                Development.Shake.Internal.Shake Development.Shake.Internal.Value
                General.Bag General.Bilist General.Binary General.Chunks
                General.Cleanup General.Concurrent General.Extra General.FileLock
                General.GetOpt General.Ids General.Intern General.ListBuilder
                General.Makefile General.Process General.Template General.Timing
                Paths_shake
abi: c3ab4ed2212347bf0991e6e43cc60219
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/shake-0.16.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/shake-0.16.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-shake
hs-libraries: HSshake-0.16.3-AgvGHj3fKO0H0wHGiwgXMo
depends:
    base-4.10.1.0 binary-0.8.5.1 bytestring-0.10.8.2 deepseq-1.4.3.0
    directory-1.3.0.2 extra-1.6.4-IR1oQDuzGtgJSLCzznTeLE
    filepath-1.4.1.2 hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    js-flot-0.8.3-BVv7WjS6mgVJLBMR8vaufn
    js-jquery-3.3.1-JZDuOLZPSWTJ3xssPMIJM6
    primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo process-1.6.1.0
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We time-1.8.0.2 transformers-0.5.2.0
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             extra-1.6.4-IR1oQDuzGtgJSLCzznTeLE=58fe223e93bb16a10e7d42b22a8195bc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             js-flot-0.8.3-BVv7WjS6mgVJLBMR8vaufn=2106e2792b3341c959c8f349c22f5bf9
             js-jquery-3.3.1-JZDuOLZPSWTJ3xssPMIJM6=df9d3b19ff8fede0e5d9f9d44e183742
             primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo=b4457a9f891c4eea587ee58a79b7f0fc
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=368a9f817c8c1b290191231dd0d81d85
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/haskell-shake/html/shake.haddock
haddock-html: /usr/share/doc/haskell-shake/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
